@@ -13,14 +13,17 @@
 #
 # Copyright Buildbot Team Members
 
+from twisted.internet import defer
+from twisted.trial import unittest
+
 from buildbot import config
-from buildbot.status.results import FAILURE
-from buildbot.status.results import SUCCESS
-from buildbot.status.results import WARNINGS
+from buildbot.process.results import FAILURE
+from buildbot.process.results import SUCCESS
+from buildbot.process.results import WARNINGS
 from buildbot.steps import python
 from buildbot.test.fake.remotecommand import ExpectShell
 from buildbot.test.util import steps
-from twisted.trial import unittest
+from buildbot.test.util.misc import TestReactorMixin
 
 log_output_success = '''\
 Making output directory...
@@ -78,10 +81,62 @@ index.rst:: WARNING: toctree contains reference to document 'preamble' that \
 doesn't have a title: no link will be generated\
 '''
 
+# this is from a run of epydoc against the buildbot source..
+epydoc_output = '''\
+  [...............
++---------------------------------------------------------------------
+| In /home/dustin/code/buildbot/t/buildbot/master/buildbot/
+| ec2.py:
+| Import failed (but source code parsing was successful).
+|     Error: ImportError: No module named boto (line 19)
+|
+  [....
+Warning: Unable to extract the base list for
+         twisted.web.resource.EncodingResourceWrapper: Bad dotted name
+  [......
++---------------------------------------------------------------------
+| In /home/dustin/code/buildbot/t/buildbot/master/buildbot/worker/
+| ec2.py:
+| Import failed (but source code parsing was successful).
+|     Error: ImportError: No module named boto (line 28)
+|
+  [...........
++---------------------------------------------------------------------
+| In /home/dustin/code/buildbot/t/buildbot/master/buildbot/status/
+| status_push.py:
+| Import failed (but source code parsing was successful).
+|     Error: ImportError: No module named status_json (line 40)
+|
+  [....................<paragraph>Special descriptor for class __provides__</paragraph>
+'''
 
-class PyLint(steps.BuildStepMixin, unittest.TestCase):
+
+class BuildEPYDoc(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
+        return self.setUpBuildStep()
+
+    def tearDown(self):
+        return self.tearDownBuildStep()
+
+    def test_sample(self):
+        self.setupStep(python.BuildEPYDoc())
+        self.expectCommands(
+            ExpectShell(workdir='wkdir', command=['make', 'epydocs'])
+            + ExpectShell.log('stdio',
+                              stdout=epydoc_output)
+            + 1,
+        )
+        self.expectOutcome(result=FAILURE,
+                           state_string='epydoc warn=1 err=3 (failure)')
+        return self.runStep()
+
+
+class PyLint(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
+
+    def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -90,44 +145,50 @@ class PyLint(steps.BuildStepMixin, unittest.TestCase):
     def test_success(self):
         self.setupStep(python.PyLint(command=['pylint']))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['pylint'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['pylint'])
             + ExpectShell.log('stdio',
                               stdout='Your code has been rated at 10/10')
             + python.PyLint.RC_OK)
-        self.expectOutcome(result=SUCCESS, status_text=['pylint'])
+        self.expectOutcome(result=SUCCESS, state_string='pylint')
         return self.runStep()
 
     def test_error(self):
         self.setupStep(python.PyLint(command=['pylint']))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['pylint'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['pylint'])
             + ExpectShell.log(
                 'stdio',
                 stdout=('W: 11: Bad indentation. Found 6 spaces, expected 4\n'
                         'E: 12: Undefined variable \'foo\'\n'))
             + (python.PyLint.RC_WARNING | python.PyLint.RC_ERROR))
         self.expectOutcome(result=FAILURE,
-                           status_text=['pylint', 'error=1', 'warning=1',
-                                        'failed'])
+                           state_string='pylint error=1 warning=1 (failure)')
         self.expectProperty('pylint-warning', 1)
         self.expectProperty('pylint-error', 1)
         return self.runStep()
 
+    def test_header_output(self):
+        self.setupStep(python.PyLint(command=['pylint']))
+        self.expectCommands(
+            ExpectShell(workdir='wkdir', command=['pylint'])
+            + ExpectShell.log(
+                'stdio',
+                header='W: 11: Bad indentation. Found 6 spaces, expected 4\n')
+            + 0)
+        self.expectOutcome(result=SUCCESS, state_string='pylint')
+        return self.runStep()
+
     def test_failure(self):
         self.setupStep(python.PyLint(command=['pylint']))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['pylint'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['pylint'])
             + ExpectShell.log(
                 'stdio',
                 stdout=('W: 11: Bad indentation. Found 6 spaces, expected 4\n'
                         'F: 13: something really strange happened\n'))
             + (python.PyLint.RC_WARNING | python.PyLint.RC_FATAL))
         self.expectOutcome(result=FAILURE,
-                           status_text=['pylint', 'fatal=1', 'warning=1',
-                                        'failed'])
+                           state_string='pylint fatal=1 warning=1 (failure)')
         self.expectProperty('pylint-warning', 1)
         self.expectProperty('pylint-fatal', 1)
         return self.runStep()
@@ -137,16 +198,14 @@ class PyLint(steps.BuildStepMixin, unittest.TestCase):
         # return code is 0, e.g. when run through a wrapper script.
         self.setupStep(python.PyLint(command=['pylint']))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['pylint'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['pylint'])
             + ExpectShell.log(
                 'stdio',
                 stdout=('W: 11: Bad indentation. Found 6 spaces, expected 4\n'
                         'E: 12: Undefined variable \'foo\'\n'))
             + 0)
         self.expectOutcome(result=FAILURE,
-                           status_text=['pylint', 'error=1', 'warning=1',
-                                        'failed'])
+                           state_string='pylint error=1 warning=1 (failure)')
         self.expectProperty('pylint-warning', 1)
         self.expectProperty('pylint-error', 1)
         return self.runStep()
@@ -154,16 +213,14 @@ class PyLint(steps.BuildStepMixin, unittest.TestCase):
     def test_regex_text(self):
         self.setupStep(python.PyLint(command=['pylint']))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['pylint'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['pylint'])
             + ExpectShell.log(
                 'stdio',
                 stdout=('W: 11: Bad indentation. Found 6 spaces, expected 4\n'
                         'C:  1:foo123: Missing docstring\n'))
             + (python.PyLint.RC_WARNING | python.PyLint.RC_CONVENTION))
         self.expectOutcome(result=WARNINGS,
-                           status_text=['pylint', 'convention=1', 'warning=1',
-                                        'warnings'])
+                           state_string='pylint convention=1 warning=1 (warnings)')
         self.expectProperty('pylint-warning', 1)
         self.expectProperty('pylint-convention', 1)
         self.expectProperty('pylint-total', 2)
@@ -173,16 +230,32 @@ class PyLint(steps.BuildStepMixin, unittest.TestCase):
         # pylint >= 0.24.0 prints out column offsets when using text format
         self.setupStep(python.PyLint(command=['pylint']))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['pylint'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['pylint'])
             + ExpectShell.log(
                 'stdio',
                 stdout=('W: 11,0: Bad indentation. Found 6 spaces, expected 4\n'
                         'C:  3,10:foo123: Missing docstring\n'))
             + (python.PyLint.RC_WARNING | python.PyLint.RC_CONVENTION))
         self.expectOutcome(result=WARNINGS,
-                           status_text=['pylint', 'convention=1', 'warning=1',
-                                        'warnings'])
+                           state_string='pylint convention=1 warning=1 (warnings)')
+        self.expectProperty('pylint-warning', 1)
+        self.expectProperty('pylint-convention', 1)
+        self.expectProperty('pylint-total', 2)
+        return self.runStep()
+
+    def test_regex_text_131(self):
+        # at least pylint 1.3.1 prints out space padded column offsets when
+        # using text format
+        self.setupStep(python.PyLint(command=['pylint']))
+        self.expectCommands(
+            ExpectShell(workdir='wkdir', command=['pylint'])
+            + ExpectShell.log(
+                'stdio',
+                stdout=('W: 11, 0: Bad indentation. Found 6 spaces, expected 4\n'
+                        'C:  3,10:foo123: Missing docstring\n'))
+            + (python.PyLint.RC_WARNING | python.PyLint.RC_CONVENTION))
+        self.expectOutcome(result=WARNINGS,
+                           state_string='pylint convention=1 warning=1 (warnings)')
         self.expectProperty('pylint-warning', 1)
         self.expectProperty('pylint-convention', 1)
         self.expectProperty('pylint-total', 2)
@@ -191,16 +264,14 @@ class PyLint(steps.BuildStepMixin, unittest.TestCase):
     def test_regex_text_ids(self):
         self.setupStep(python.PyLint(command=['pylint']))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['pylint'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['pylint'])
             + ExpectShell.log(
                 'stdio',
                 stdout=('W0311: 11: Bad indentation.\n'
                         'C0111:  1:funcName: Missing docstring\n'))
             + (python.PyLint.RC_WARNING | python.PyLint.RC_CONVENTION))
         self.expectOutcome(result=WARNINGS,
-                           status_text=['pylint', 'convention=1', 'warning=1',
-                                        'warnings'])
+                           state_string='pylint convention=1 warning=1 (warnings)')
         self.expectProperty('pylint-warning', 1)
         self.expectProperty('pylint-convention', 1)
         self.expectProperty('pylint-total', 2)
@@ -210,16 +281,14 @@ class PyLint(steps.BuildStepMixin, unittest.TestCase):
         # pylint >= 0.24.0 prints out column offsets when using text format
         self.setupStep(python.PyLint(command=['pylint']))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['pylint'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['pylint'])
             + ExpectShell.log(
                 'stdio',
                 stdout=('W0311: 11,0: Bad indentation.\n'
                         'C0111:  3,10:foo123: Missing docstring\n'))
             + (python.PyLint.RC_WARNING | python.PyLint.RC_CONVENTION))
         self.expectOutcome(result=WARNINGS,
-                           status_text=['pylint', 'convention=1', 'warning=1',
-                                        'warnings'])
+                           state_string='pylint convention=1 warning=1 (warnings)')
         self.expectProperty('pylint-warning', 1)
         self.expectProperty('pylint-convention', 1)
         self.expectProperty('pylint-total', 2)
@@ -228,16 +297,14 @@ class PyLint(steps.BuildStepMixin, unittest.TestCase):
     def test_regex_parseable_ids(self):
         self.setupStep(python.PyLint(command=['pylint']))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['pylint'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['pylint'])
             + ExpectShell.log(
                 'stdio',
                 stdout=('test.py:9: [W0311] Bad indentation.\n'
                         'test.py:3: [C0111, foo123] Missing docstring\n'))
             + (python.PyLint.RC_WARNING | python.PyLint.RC_CONVENTION))
         self.expectOutcome(result=WARNINGS,
-                           status_text=['pylint', 'convention=1', 'warning=1',
-                                        'warnings'])
+                           state_string='pylint convention=1 warning=1 (warnings)')
         self.expectProperty('pylint-warning', 1)
         self.expectProperty('pylint-convention', 1)
         self.expectProperty('pylint-total', 2)
@@ -246,25 +313,44 @@ class PyLint(steps.BuildStepMixin, unittest.TestCase):
     def test_regex_parseable(self):
         self.setupStep(python.PyLint(command=['pylint']))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['pylint'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['pylint'])
             + ExpectShell.log(
                 'stdio',
                 stdout=('test.py:9: [W] Bad indentation.\n'
                         'test.py:3: [C, foo123] Missing docstring\n'))
             + (python.PyLint.RC_WARNING | python.PyLint.RC_CONVENTION))
         self.expectOutcome(result=WARNINGS,
-                           status_text=['pylint', 'convention=1', 'warning=1',
-                                        'warnings'])
+                           state_string='pylint convention=1 warning=1 (warnings)')
+        self.expectProperty('pylint-warning', 1)
+        self.expectProperty('pylint-convention', 1)
+        self.expectProperty('pylint-total', 2)
+        return self.runStep()
+
+    def test_regex_parseable_131(self):
+        """ In pylint 1.3.1, output parseable is deprecated, but looks like
+        that, this is also the new recommended format string:
+            --msg-template={path}:{line}: [{msg_id}({symbol}), {obj}] {msg}
+        """
+        self.setupStep(python.PyLint(command=['pylint']))
+        self.expectCommands(
+            ExpectShell(workdir='wkdir', command=['pylint'])
+            + ExpectShell.log(
+                'stdio',
+                stdout=('test.py:9: [W0311(bad-indentation), ] Bad indentation. Found 6 spaces, expected 4\n'
+                        'test.py:3: [C0111(missing-docstring), myFunc] Missing function docstring\n'))
+            + (python.PyLint.RC_WARNING | python.PyLint.RC_CONVENTION))
+        self.expectOutcome(result=WARNINGS,
+                           state_string='pylint convention=1 warning=1 (warnings)')
         self.expectProperty('pylint-warning', 1)
         self.expectProperty('pylint-convention', 1)
         self.expectProperty('pylint-total', 2)
         return self.runStep()
 
 
-class PyFlakes(steps.BuildStepMixin, unittest.TestCase):
+class PyFlakes(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
@@ -273,23 +359,33 @@ class PyFlakes(steps.BuildStepMixin, unittest.TestCase):
     def test_success(self):
         self.setupStep(python.PyFlakes())
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'])
             + 0)
-        self.expectOutcome(result=SUCCESS, status_text=['pyflakes'])
+        self.expectOutcome(result=SUCCESS, state_string='pyflakes')
+        return self.runStep()
+
+    def test_content_in_header(self):
+        self.setupStep(python.PyFlakes())
+        self.expectCommands(
+            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'])
+            + ExpectShell.log(
+                'stdio',
+                # don't match pyflakes-like output in the header
+                header="foo.py:1: 'bar' imported but unused\n")
+            + 0)
+        self.expectOutcome(result=0, state_string='pyflakes')
         return self.runStep()
 
     def test_unused(self):
         self.setupStep(python.PyFlakes())
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'])
             + ExpectShell.log(
                 'stdio',
                 stdout="foo.py:1: 'bar' imported but unused\n")
             + 1)
         self.expectOutcome(result=WARNINGS,
-                           status_text=['pyflakes', 'unused=1', 'warnings'])
+                           state_string='pyflakes unused=1 (warnings)')
         self.expectProperty('pyflakes-unused', 1)
         self.expectProperty('pyflakes-total', 1)
         return self.runStep()
@@ -297,14 +393,13 @@ class PyFlakes(steps.BuildStepMixin, unittest.TestCase):
     def test_undefined(self):
         self.setupStep(python.PyFlakes())
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'])
             + ExpectShell.log(
                 'stdio',
                 stdout="foo.py:1: undefined name 'bar'\n")
             + 1)
         self.expectOutcome(result=FAILURE,
-                           status_text=['pyflakes', 'undefined=1', 'failed'])
+                           state_string='pyflakes undefined=1 (failure)')
         self.expectProperty('pyflakes-undefined', 1)
         self.expectProperty('pyflakes-total', 1)
         return self.runStep()
@@ -312,14 +407,13 @@ class PyFlakes(steps.BuildStepMixin, unittest.TestCase):
     def test_redefs(self):
         self.setupStep(python.PyFlakes())
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'])
             + ExpectShell.log(
                 'stdio',
                 stdout="foo.py:2: redefinition of unused 'foo' from line 1\n")
             + 1)
         self.expectOutcome(result=WARNINGS,
-                           status_text=['pyflakes', 'redefs=1', 'warnings'])
+                           state_string='pyflakes redefs=1 (warnings)')
         self.expectProperty('pyflakes-redefs', 1)
         self.expectProperty('pyflakes-total', 1)
         return self.runStep()
@@ -327,14 +421,13 @@ class PyFlakes(steps.BuildStepMixin, unittest.TestCase):
     def test_importstar(self):
         self.setupStep(python.PyFlakes())
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'])
             + ExpectShell.log(
                 'stdio',
                 stdout="foo.py:1: 'from module import *' used; unable to detect undefined names\n")
             + 1)
         self.expectOutcome(result=WARNINGS,
-                           status_text=['pyflakes', 'import*=1', 'warnings'])
+                           state_string='pyflakes import*=1 (warnings)')
         self.expectProperty('pyflakes-import*', 1)
         self.expectProperty('pyflakes-total', 1)
         return self.runStep()
@@ -342,90 +435,89 @@ class PyFlakes(steps.BuildStepMixin, unittest.TestCase):
     def test_misc(self):
         self.setupStep(python.PyFlakes())
         self.expectCommands(
-            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'],
-                        usePTY='slave-config')
+            ExpectShell(workdir='wkdir', command=['make', 'pyflakes'])
             + ExpectShell.log(
                 'stdio',
                 stdout="foo.py:2: redefinition of function 'bar' from line 1\n")
             + 1)
         self.expectOutcome(result=WARNINGS,
-                           status_text=['pyflakes', 'misc=1', 'warnings'])
+                           state_string='pyflakes misc=1 (warnings)')
         self.expectProperty('pyflakes-misc', 1)
         self.expectProperty('pyflakes-total', 1)
         return self.runStep()
 
 
-class TestSphinx(steps.BuildStepMixin, unittest.TestCase):
+class TestSphinx(steps.BuildStepMixin, TestReactorMixin, unittest.TestCase):
 
     def setUp(self):
+        self.setUpTestReactor()
         return self.setUpBuildStep()
 
     def tearDown(self):
         return self.tearDownBuildStep()
 
     def test_builddir_required(self):
-        self.assertRaises(config.ConfigErrors, lambda:
-                          python.Sphinx())
+        with self.assertRaises(config.ConfigErrors):
+            python.Sphinx()
 
     def test_bad_mode(self):
-        self.assertRaises(config.ConfigErrors, lambda: python.Sphinx(
-            sphinx_builddir="_build", mode="don't care"))
+        with self.assertRaises(config.ConfigErrors):
+            python.Sphinx(sphinx_builddir="_build", mode="don't care")
 
     def test_success(self):
         self.setupStep(python.Sphinx(sphinx_builddir="_build"))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', usePTY='slave-config',
+            ExpectShell(workdir='wkdir',
                         command=['sphinx-build', '.', '_build'])
             + ExpectShell.log('stdio',
                               stdout=log_output_success)
             + 0
         )
-        self.expectOutcome(result=SUCCESS, status_text=["sphinx", "0 warnings"])
+        self.expectOutcome(result=SUCCESS, state_string="sphinx 0 warnings")
         return self.runStep()
 
     def test_failure(self):
         self.setupStep(python.Sphinx(sphinx_builddir="_build"))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', usePTY='slave-config',
+            ExpectShell(workdir='wkdir',
                         command=['sphinx-build', '.', '_build'])
             + ExpectShell.log('stdio',
                               stdout='oh noes!')
             + 1
         )
-        self.expectOutcome(result=FAILURE, status_text=["sphinx", "0 warnings", "failed"])
+        self.expectOutcome(result=FAILURE,
+                           state_string="sphinx 0 warnings (failure)")
         return self.runStep()
 
     def test_nochange(self):
         self.setupStep(python.Sphinx(sphinx_builddir="_build"))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', usePTY='slave-config',
+            ExpectShell(workdir='wkdir',
                         command=['sphinx-build', '.', '_build'])
             + ExpectShell.log('stdio',
                               stdout=log_output_nochange)
             + 0
         )
         self.expectOutcome(result=SUCCESS,
-                           status_text=["sphinx", "0 warnings"])
+                           state_string="sphinx 0 warnings")
         return self.runStep()
 
+    @defer.inlineCallbacks
     def test_warnings(self):
         self.setupStep(python.Sphinx(sphinx_builddir="_build"))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', usePTY='slave-config',
+            ExpectShell(workdir='wkdir',
                         command=['sphinx-build', '.', '_build'])
             + ExpectShell.log('stdio',
                               stdout=log_output_warnings)
             + 0
         )
         self.expectOutcome(result=WARNINGS,
-                           status_text=["sphinx", "2 warnings", "warnings"])
+                           state_string="sphinx 2 warnings (warnings)")
         self.expectLogfile("warnings", warnings)
-        d = self.runStep()
+        yield self.runStep()
 
-        def check(_):
-            self.assertEqual(self.step_statistics, {'warnings': 2})
-        d.addCallback(check)
-        return d
+        self.assertEqual(self.step.statistics, {'warnings': 2})
 
     def test_constr_args(self):
         self.setupStep(python.Sphinx(sphinx_sourcedir='src',
@@ -433,10 +525,11 @@ class TestSphinx(steps.BuildStepMixin, unittest.TestCase):
                                      sphinx_builder='css',
                                      sphinx="/path/to/sphinx-build",
                                      tags=['a', 'b'],
-                                     defines=dict(empty=None, t=True, f=False, s="str"),
+                                     defines=dict(
+                                         empty=None, t=True, f=False, s="str"),
                                      mode='full'))
         self.expectCommands(
-            ExpectShell(workdir='wkdir', usePTY='slave-config',
+            ExpectShell(workdir='wkdir',
                         command=['/path/to/sphinx-build', '-b', 'css',
                                  '-t', 'a', '-t', 'b', '-D', 'empty',
                                  '-D', 'f=0', '-D', 's=str', '-D', 't=1',
@@ -445,5 +538,5 @@ class TestSphinx(steps.BuildStepMixin, unittest.TestCase):
                               stdout=log_output_success)
             + 0
         )
-        self.expectOutcome(result=SUCCESS, status_text=["sphinx", "0 warnings"])
+        self.expectOutcome(result=SUCCESS, state_string="sphinx 0 warnings")
         return self.runStep()
